﻿--[[ Postal_Forward: Add a Forward Button to Mails ]]--

assert( Postal, "Postal not found!")

------------------------------
--      Are you local?      --
------------------------------

local postallib = AceLibrary("PostalLib-1.0")
local baglib = AceLibrary("BagLib-1.0")
local L = AceLibrary("AceLocale-2.2"):new("Postal")

local inventoryTable = nil
local button = nil
local openMail = nil

local noop = function() end

----------------------------------
--      Module Declaration      --
----------------------------------

Postal_Forward = Postal:NewModule("Forward")
Postal_Forward.revision = tonumber(string.sub("$Revision: 54976 $", 12, -3))

function Postal_Forward:OnEnable()
	if not button then
		button = CreateFrame("Button", "OpenMailForwardButton", OpenMailFrame, "UIPanelButtonTemplate")
		button:SetWidth(82)
		button:SetHeight(22)
		button:SetPoint("RIGHT", OpenMailReplyButton, "LEFT", 0, 0)
		button:SetText(L["Forward"])
		button:SetScript("OnClick", function()
			self:OpenForward()
		end)
	end

	self:RegisterEvent("MAIL_SHOW")
	self:RegisterEvent("MAIL_CLOSED", "Reset")	-- Required for AddonLoader
	self:RegisterEvent("PLAYER_LEAVING_WORLD", "Reset")
end

function Postal_Forward:MAIL_SHOW()
	self:RegisterEvent("MAIL_CLOSED", "Reset")
end

function Postal_Forward:OpenForward()
	OpenMail_Reply()

	openMail = InboxFrame.openMailID

	local money = select(5, GetInboxHeaderInfo(openMail))
	if money and money > 0 then
		MoneyInputFrame_SetCopper(SendMailMoney, money)
		SetSendMailMoney(money)
	end

	SendMailNameEditBox:SetText("")
	local prefix = L["FW:"]
	local subject = OpenMailSubject:GetText()
	if subject:sub(1, prefix:len()) ~= prefix then
		subject = prefix.." "..subject
	end
	SendMailSubjectEditBox:SetText(subject or "")

	SendMailBodyEditBox:SetText(string.gsub(OpenMailBodyText:GetText() or "", "\n", "\n>"))
	SendMailNameEditBox:SetFocus()

	HideUIPanel(OpenMailFrame)
	self:ToggleForward(1)
end

function Postal_Forward:SendMailMailButton_OnClick()
	inventoryTable = nil
	if GetInboxItem(openMail) then
		inventoryTable = baglib:GetSlotTable()
	end
	self:RegisterEvent("Postal10_MailSkipped", "Reset", true)
	self:RegisterEvent("Postal10_MailPurged", "Send", true)

	postallib:PurgeMail(openMail)
	SendMailMailButton:Disable()
end

function Postal_Forward:Send()
	if inventoryTable then
		local bag, slot = baglib:FindTakenSlot(inventoryTable)
		PickupContainerItem(bag, slot)
		ClickSendMailItemButton()
	end

	self:RegisterEvent("MAIL_SEND_SUCCESS", "Reset")
	SendMailFrame_SendMail()
	SendMailMailButton:Disable()
end

function Postal_Forward:InboxFrame_OnClick(index)
	self.hooks["InboxFrame_OnClick"](index)

	local COD = select(6, GetInboxHeaderInfo(index))
	if COD and COD > 0 then
		button:Disable()
	else
		button:Enable()
	end
end

function Postal_Forward:ToggleForward(toggle)
	if toggle then
		button:Disable()

		if not self:IsHooked(SendMailPackageButton, "OnEnter") then
			self:HookScript(SendMailPackageButton, "OnEnter", noop)
		end

		SendMailCODButton:Disable()
		postallib:DisableAttachments(1)

		if not self:IsHooked("SendMailMailButton_OnClick") then
			self:Hook("SendMailMailButton_OnClick", true)
		end
		if not self:IsHooked("SendMailPackageButton_OnClick") then
			self:Hook("SendMailPackageButton_OnClick", noop, true)
		end
	else
		button:Enable()

		if self:IsHooked("SendMailPackageButton_OnEnter") then
			self:Unhook("SendMailPackageButton_OnEnter")
		end

		SendMailCODButton:Enable()
		postallib:DisableAttachments(nil)

		if self:IsHooked("SendMailMailButton_OnClick") then
			self:Unhook("SendMailMailButton_OnClick")
		end
		if self:IsHooked("SendMailPackageButton_OnClick") then
			self:Unhook("SendMailPackageButton_OnClick")
		end
	end
end

function Postal_Forward:Reset()
	self:ToggleForward()
	if self:IsEventRegistered("MAIL_SEND_SUCCESS") then
		self:UnregisterEvent("MAIL_SEND_SUCCESS")
	end
	if self:IsEventRegistered("Postal10_MailSkipped") then
		self:UnregisterEvent("Postal10_MailSkipped")
	end
	if self:IsEventRegistered("Postal10_MailPurged") then
		self:UnregisterEvent("Postal10_MailPurged")
	end
	if (event ~= "MAIL_CLOSED" and event ~= "PLAYER_LEAVING_WORLD") then
		MailFrameTab_OnClick(1)
	else
		self:UnregisterEvent("MAIL_CLOSED")
	end
end

